@@ -12,7 +12,7 @@ import tempfile
 
 from cookiecutter import utils
 from cookiecutter.environment import StrictEnvironment
-from .exceptions import FailedHookException
+from cookiecutter.exceptions import FailedHookException
 
 logger = logging.getLogger(__name__)
 
@@ -52,10 +52,10 @@ def find_hook(hook_name, hooks_dir='hooks'):
     :param hooks_dir: The hook directory in the template
     :return: The absolute path to the hook script or None
     """
-    logger.debug('hooks_dir is {}'.format(os.path.abspath(hooks_dir)))
+    logger.debug('hooks_dir is %s', os.path.abspath(hooks_dir))
 
     if not os.path.isdir(hooks_dir):
-        logger.debug('No hooks/ dir in template_dir')
+        logger.debug('No hooks/dir in template_dir')
         return None
 
     for hook_file in os.listdir(hooks_dir):
@@ -80,11 +80,7 @@ def run_script(script_path, cwd='.'):
     utils.make_executable(script_path)
 
     try:
-        proc = subprocess.Popen(
-            script_command,
-            shell=run_thru_shell,
-            cwd=cwd
-        )
+        proc = subprocess.Popen(script_command, shell=run_thru_shell, cwd=cwd)
         exit_status = proc.wait()
         if exit_status != EXIT_SUCCESS:
             raise FailedHookException(
@@ -93,12 +89,9 @@ def run_script(script_path, cwd='.'):
     except OSError as os_error:
         if os_error.errno == errno.ENOEXEC:
             raise FailedHookException(
-                'Hook script failed, might be an '
-                'empty file or missing a shebang'
+                'Hook script failed, might be an ' 'empty file or missing a shebang'
             )
-        raise FailedHookException(
-            'Hook script failed (error: {})'.format(os_error)
-        )
+        raise FailedHookException('Hook script failed (error: {})'.format(os_error))
 
 
 def run_script_with_context(script_path, cwd, context):
@@ -110,17 +103,11 @@ def run_script_with_context(script_path, cwd, context):
     """
     _, extension = os.path.splitext(script_path)
 
-    contents = io.open(script_path, 'r', encoding='utf-8').read()
+    with io.open(script_path, 'r', encoding='utf-8') as file:
+        contents = file.read()
 
-    with tempfile.NamedTemporaryFile(
-        delete=False,
-        mode='wb',
-        suffix=extension
-    ) as temp:
-        env = StrictEnvironment(
-            context=context,
-            keep_trailing_newline=True,
-        )
+    with tempfile.NamedTemporaryFile(delete=False, mode='wb', suffix=extension) as temp:
+        env = StrictEnvironment(context=context, keep_trailing_newline=True)
         template = env.from_string(contents)
         output = template.render(**context)
         temp.write(output.encode('utf-8'))
@@ -138,7 +125,7 @@ def run_hook(hook_name, project_dir, context):
     """
     script = find_hook(hook_name)
     if script is None:
-        logger.debug('No {} hook found'.format(hook_name))
+        logger.debug('No %s hook found', hook_name)
         return
-    logger.debug('Running hook {}'.format(hook_name))
+    logger.debug('Running hook %s', hook_name)
     run_script_with_context(script, project_dir, context)
