@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 
+"""Module for setting up logging."""
+
 import logging
 import sys
 
@@ -18,6 +20,11 @@ LOG_FORMATS = {
 
 
 def configure_logger(stream_level='DEBUG', debug_file=None):
+    """Configure logging for cookiecutter.
+
+    Set up logging to stdout with given level. If ``debug_file`` is given set
+    up logging to file with DEBUG level.
+    """
     # Set up 'cookiecutter' logger
     logger = logging.getLogger('cookiecutter')
     logger.setLevel(logging.DEBUG)
