@@ -7,12 +7,18 @@ import logging
 import os
 import subprocess
 
-from whichcraft import which
+try:
+    from shutil import which
+except ImportError:
+    from whichcraft import which
 
-from .exceptions import (
-    RepositoryNotFound, RepositoryCloneFailed, UnknownRepoType, VCSNotInstalled
+from cookiecutter.exceptions import (
+    RepositoryNotFound,
+    RepositoryCloneFailed,
+    UnknownRepoType,
+    VCSNotInstalled,
 )
-from .utils import make_sure_path_exists, prompt_and_delete
+from cookiecutter.utils import make_sure_path_exists, prompt_and_delete
 
 logger = logging.getLogger(__name__)
 
@@ -80,11 +86,10 @@ def clone(repo_url, checkout=None, clone_to_dir='.', no_input=False):
     repo_url = repo_url.rstrip('/')
     tail = os.path.split(repo_url)[1]
     if repo_type == 'git':
-        repo_dir = os.path.normpath(os.path.join(clone_to_dir,
-                                                 tail.rsplit('.git')[0]))
+        repo_dir = os.path.normpath(os.path.join(clone_to_dir, tail.rsplit('.git')[0]))
     elif repo_type == 'hg':
         repo_dir = os.path.normpath(os.path.join(clone_to_dir, tail))
-    logger.debug('repo_dir is {0}'.format(repo_dir))
+    logger.debug('repo_dir is %s', repo_dir)
 
     if os.path.isdir(repo_dir):
         clone = prompt_and_delete(repo_dir, no_input=no_input)
