@@ -1,4 +1,7 @@
 # -*- coding: utf-8 -*-
+
+"""Collection of tests around cloning cookiecutter template repositories."""
+
 import os
 
 import pytest
@@ -6,21 +9,24 @@ import pytest
 from cookiecutter import repository, exceptions
 
 
-@pytest.mark.parametrize('template, is_url', [
-    ('/path/to/zipfile.zip', False),
-    ('https://example.com/path/to/zipfile.zip', True),
-    ('http://example.com/path/to/zipfile.zip', True),
-])
+@pytest.mark.parametrize(
+    'template, is_url',
+    [
+        ('/path/to/zipfile.zip', False),
+        ('https://example.com/path/to/zipfile.zip', True),
+        ('http://example.com/path/to/zipfile.zip', True),
+    ],
+)
 def test_zipfile_unzip(mocker, template, is_url, user_config_data):
-    """`unzip()` should be called with correct args when
-    `determine_repo_dir()` is passed a zipfile, or a URL
-    to a zipfile.
-    """
+    """Verify zip files correctly handled for different source locations.
 
+    `unzip()` should be called with correct args when `determine_repo_dir()`
+    is passed a zipfile, or a URL to a zipfile.
+    """
     mock_clone = mocker.patch(
         'cookiecutter.repository.unzip',
         return_value='tests/fake-repo-tmpl',
-        autospec=True
+        autospec=True,
     )
 
     project_dir, cleanup = repository.determine_repo_dir(
@@ -54,16 +60,16 @@ def template_url():
     return 'https://github.com/pytest-dev/cookiecutter-pytest-plugin.git'
 
 
-def test_repository_url_should_clone(
-        mocker, template_url, user_config_data):
-    """`clone()` should be called with correct args when
-    `determine_repo_dir()` is passed a repository template url.
-    """
+def test_repository_url_should_clone(mocker, template_url, user_config_data):
+    """Verify repository url triggers clone function.
 
+    `clone()` should be called with correct args when `determine_repo_dir()` is
+    passed a repository template url.
+    """
     mock_clone = mocker.patch(
         'cookiecutter.repository.clone',
         return_value='tests/fake-repo-tmpl',
-        autospec=True
+        autospec=True,
     )
 
     project_dir, cleanup = repository.determine_repo_dir(
@@ -71,14 +77,14 @@ def test_repository_url_should_clone(
         abbreviations={},
         clone_to_dir=user_config_data['cookiecutters_dir'],
         checkout=None,
-        no_input=True
+        no_input=True,
     )
 
     mock_clone.assert_called_once_with(
         repo_url=template_url,
         checkout=None,
         clone_to_dir=user_config_data['cookiecutters_dir'],
-        no_input=True
+        no_input=True,
     )
 
     assert os.path.isdir(project_dir)
@@ -86,12 +92,12 @@ def test_repository_url_should_clone(
     assert 'tests/fake-repo-tmpl' == project_dir
 
 
-def test_repository_url_with_no_context_file(
-        mocker, template_url, user_config_data):
+def test_repository_url_with_no_context_file(mocker, template_url, user_config_data):
+    """Verify cloned repository without `cookiecutter.json` file raises error."""
     mocker.patch(
         'cookiecutter.repository.clone',
         return_value='tests/fake-repo-bad',
-        autospec=True
+        autospec=True,
     )
 
     with pytest.raises(exceptions.RepositoryNotFound) as err:
@@ -100,13 +106,10 @@ def test_repository_url_with_no_context_file(
             abbreviations={},
             clone_to_dir=None,
             checkout=None,
-            no_input=True
+            no_input=True,
         )
 
     assert str(err.value) == (
         'A valid repository for "{}" could not be found in the following '
-        'locations:\n{}'.format(
-            template_url,
-            'tests/fake-repo-bad',
-        )
+        'locations:\n{}'.format(template_url, 'tests/fake-repo-bad')
     )
