@@ -1,6 +1,10 @@
 # -*- coding: utf-8 -*-
+
+"""Tests around detection whether cookiecutter templates are cached locally."""
+
 import io
 import os
+
 import pytest
 
 from cookiecutter import repository
@@ -8,11 +12,13 @@ from cookiecutter import repository
 
 @pytest.fixture
 def template():
+    """Fixture. Return simple string as template name."""
     return 'cookiecutter-pytest-plugin'
 
 
 @pytest.fixture
 def cloned_cookiecutter_path(user_config_data, template):
+    """Fixture. Create fake project directory in special user folder."""
     cookiecutters_dir = user_config_data['cookiecutters_dir']
 
     cloned_template_path = os.path.join(cookiecutters_dir, template)
@@ -24,9 +30,15 @@ def cloned_cookiecutter_path(user_config_data, template):
 
 
 def test_should_find_existing_cookiecutter(
-        template, user_config_data, cloned_cookiecutter_path):
+    template, user_config_data, cloned_cookiecutter_path
+):
+    """
+    Should find folder created by `cloned_cookiecutter_path` and return it.
+
+    This folder is considered like previously cloned project directory.
+    """
     project_dir, cleanup = repository.determine_repo_dir(
-        template,
+        template=template,
         abbreviations={},
         clone_to_dir=user_config_data['cookiecutters_dir'],
         checkout=None,
