@@ -1,9 +1,13 @@
 # -*- coding: utf-8 -*-
+
+"""Tests around using locally cached cookiecutter template repositories."""
+
 import os
-from cookiecutter import repository, exceptions
 
 import pytest
 
+from cookiecutter import repository, exceptions
+
 
 def test_finds_local_repo(tmpdir):
     """A valid local repository should be returned."""
@@ -12,7 +16,7 @@ def test_finds_local_repo(tmpdir):
         abbreviations={},
         clone_to_dir=str(tmpdir),
         checkout=None,
-        no_input=True
+        no_input=True,
     )
 
     assert 'tests/fake-repo' == project_dir
@@ -20,9 +24,8 @@ def test_finds_local_repo(tmpdir):
 
 
 def test_local_repo_with_no_context_raises(tmpdir):
-    """A local repository without a cookiecutter.json should raise a
-    `RepositoryNotFound` exception.
-    """
+    """A local repository without a cookiecutter.json should raise a \
+    `RepositoryNotFound` exception."""
     template_path = os.path.join('tests', 'fake-repo-bad')
     with pytest.raises(exceptions.RepositoryNotFound) as err:
         repository.determine_repo_dir(
@@ -30,25 +33,21 @@ def test_local_repo_with_no_context_raises(tmpdir):
             abbreviations={},
             clone_to_dir=str(tmpdir),
             checkout=None,
-            no_input=True
+            no_input=True,
         )
 
     assert str(err.value) == (
         'A valid repository for "{}" could not be found in the following '
         'locations:\n{}'.format(
             template_path,
-            '\n'.join([
-                template_path,
-                str(tmpdir / 'tests/fake-repo-bad')
-            ]),
+            '\n'.join([template_path, str(tmpdir / 'tests/fake-repo-bad')]),
         )
     )
 
 
 def test_local_repo_typo(tmpdir):
-    """An unknown local repository should raise a `RepositoryNotFound`
-    exception.
-    """
+    """An unknown local repository should raise a `RepositoryNotFound` \
+    exception."""
     template_path = os.path.join('tests', 'unknown-repo')
     with pytest.raises(exceptions.RepositoryNotFound) as err:
         repository.determine_repo_dir(
@@ -56,16 +55,13 @@ def test_local_repo_typo(tmpdir):
             abbreviations={},
             clone_to_dir=str(tmpdir),
             checkout=None,
-            no_input=True
+            no_input=True,
         )
 
     assert str(err.value) == (
         'A valid repository for "{}" could not be found in the following '
         'locations:\n{}'.format(
             template_path,
-            '\n'.join([
-                template_path,
-                str(tmpdir / 'tests/unknown-repo')
-            ]),
+            '\n'.join([template_path, str(tmpdir / 'tests/unknown-repo')]),
         )
     )
