@@ -1,17 +1,10 @@
 # -*- coding: utf-8 -*-
 
-"""
-test_get_user_config
---------------------
-
-Tests formerly known from a unittest residing in test_config.py named
-TestGetUserConfig.test_get_user_config_valid
-TestGetUserConfig.test_get_user_config_invalid
-TestGetUserConfig.test_get_user_config_nonexistent
-"""
+"""Tests to verify correct work with user configs and system/user variables inside."""
 
 import os
 import shutil
+
 import pytest
 
 from cookiecutter import config
@@ -20,13 +13,15 @@ from cookiecutter.exceptions import InvalidConfiguration
 
 @pytest.fixture(scope='module')
 def user_config_path():
+    """Fixture. Return user config path for current user."""
     return os.path.expanduser('~/.cookiecutterrc')
 
 
 @pytest.fixture(scope='function')
-def back_up_rc(request, user_config_path):
+def back_up_rc(user_config_path):
     """
     Back up an existing cookiecutter rc and restore it after the test.
+
     If ~/.cookiecutterrc is pre-existing, move it to a temp location
     """
     user_config_path_backup = os.path.expanduser('~/.cookiecutterrc.backup')
@@ -35,30 +30,20 @@ def back_up_rc(request, user_config_path):
         shutil.copy(user_config_path, user_config_path_backup)
         os.remove(user_config_path)
 
-    def remove_test_rc():
-        """
-        Remove the ~/.cookiecutterrc that has been created in the test.
-        """
-        if os.path.exists(user_config_path):
-            os.remove(user_config_path)
+    yield
+    # Remove the ~/.cookiecutterrc that has been created in the test.
+    if os.path.exists(user_config_path):
+        os.remove(user_config_path)
 
-    def restore_original_rc():
-        """
-        If it existed, restore the original ~/.cookiecutterrc
-        """
-        if os.path.exists(user_config_path_backup):
-            shutil.copy(user_config_path_backup, user_config_path)
-            os.remove(user_config_path_backup)
-
-    # According to the py.test source code finalizers are popped from an
-    # internal list that we populated via 'addfinalizer'. As a result the
-    # last-added finalizer function is executed first.
-    request.addfinalizer(restore_original_rc)
-    request.addfinalizer(remove_test_rc)
+    # If it existed, restore the original ~/.cookiecutterrc.
+    if os.path.exists(user_config_path_backup):
+        shutil.copy(user_config_path_backup, user_config_path)
+        os.remove(user_config_path_backup)
 
 
 @pytest.fixture
 def custom_config():
+    """Fixture. Return expected custom configuration for future tests validation."""
     return {
         'default_context': {
             'full_name': 'Firstname Lastname',
@@ -72,15 +57,13 @@ def custom_config():
             'gl': 'https://gitlab.com/{0}.git',
             'bb': 'https://bitbucket.org/{0}',
             'helloworld': 'https://github.com/hackebrot/helloworld',
-        }
+        },
     }
 
 
 @pytest.mark.usefixtures('back_up_rc')
 def test_get_user_config_valid(user_config_path, custom_config):
-    """
-    Get config from a valid ~/.cookiecutterrc file
-    """
+    """Validate user config correctly parsed if exist and correctly formatted."""
     shutil.copy('tests/test-config/valid-config.yaml', user_config_path)
     conf = config.get_user_config()
 
@@ -89,9 +72,7 @@ def test_get_user_config_valid(user_config_path, custom_config):
 
 @pytest.mark.usefixtures('back_up_rc')
 def test_get_user_config_invalid(user_config_path):
-    """
-    Get config from an invalid ~/.cookiecutterrc file
-    """
+    """Validate `InvalidConfiguration` raised when provided user config malformed."""
     shutil.copy('tests/test-config/invalid-config.yaml', user_config_path)
     with pytest.raises(InvalidConfiguration):
         config.get_user_config()
@@ -99,18 +80,18 @@ def test_get_user_config_invalid(user_config_path):
 
 @pytest.mark.usefixtures('back_up_rc')
 def test_get_user_config_nonexistent():
-    """
-    Get config from a nonexistent ~/.cookiecutterrc file
-    """
+    """Validate default app config returned, if user does not have own config."""
     assert config.get_user_config() == config.DEFAULT_CONFIG
 
 
 @pytest.fixture
-def custom_config_path(custom_config):
+def custom_config_path():
+    """Fixture. Return path to custom user config for tests."""
     return 'tests/test-config/valid-config.yaml'
 
 
 def test_specify_config_path(mocker, custom_config_path, custom_config):
+    """Validate provided custom config path should be respected and parsed."""
     spy_get_config = mocker.spy(config, 'get_config')
 
     user_config = config.get_user_config(custom_config_path)
@@ -120,29 +101,36 @@ def test_specify_config_path(mocker, custom_config_path, custom_config):
 
 
 def test_default_config_path(user_config_path):
+    """Validate app configuration. User config path should match default path."""
     assert config.USER_CONFIG_PATH == user_config_path
 
 
 def test_default_config_from_env_variable(
-        monkeypatch, custom_config_path, custom_config):
+    monkeypatch, custom_config_path, custom_config
+):
+    """Validate app configuration. User config path should be parsed from sys env."""
     monkeypatch.setenv('COOKIECUTTER_CONFIG', custom_config_path)
 
     user_config = config.get_user_config()
     assert user_config == custom_config
 
 
-def test_force_default_config(mocker):
+def test_force_default_config(mocker, custom_config_path):
+    """Validate `default_config=True` should ignore provided custom user config."""
     spy_get_config = mocker.spy(config, 'get_config')
 
-    user_config = config.get_user_config(None, default_config=True)
+    user_config = config.get_user_config(custom_config_path, default_config=True)
 
     assert user_config == config.DEFAULT_CONFIG
     assert not spy_get_config.called
 
 
 def test_expand_user_for_directories_in_config(monkeypatch):
+    """Validate user pointers expanded in user configs."""
+
     def _expanduser(path):
         return path.replace('~', 'Users/bob')
+
     monkeypatch.setattr('os.path.expanduser', _expanduser)
 
     config_file = 'tests/test-config/config-expand-user.yaml'
@@ -153,6 +141,7 @@ def test_expand_user_for_directories_in_config(monkeypatch):
 
 
 def test_expand_vars_for_directories_in_config(monkeypatch):
+    """Validate environment variables expanded in user configs."""
     monkeypatch.setenv('COOKIES', 'Users/bob/cookies')
 
     config_file = 'tests/test-config/config-expand-vars.yaml'
