@@ -1,11 +1,16 @@
 # -*- coding: utf-8 -*-
+
+"""Collection of tests around cookiecutter's replay feature."""
+
 from cookiecutter.main import cookiecutter
 
 
 def test_replay_dump_template_name(
-        monkeypatch, mocker, user_config_data, user_config_file):
-    """Check that replay_dump is called with a valid template_name that is
-    not a relative path.
+    monkeypatch, mocker, user_config_data, user_config_file
+):
+    """Check that replay_dump is called with a valid template_name.
+
+    Template name must not be a relative path.
 
     Otherwise files such as ``..json`` are created, which are not just cryptic
     but also later mistaken for replay files of other templates if invoked with
@@ -20,23 +25,20 @@ def test_replay_dump_template_name(
     mocker.patch('cookiecutter.main.generate_files')
 
     cookiecutter(
-        '.',
-        no_input=True,
-        replay=False,
-        config_file=user_config_file,
+        '.', no_input=True, replay=False, config_file=user_config_file,
     )
 
     mock_replay_dump.assert_called_once_with(
-        user_config_data['replay_dir'],
-        'fake-repo-tmpl',
-        mocker.ANY,
+        user_config_data['replay_dir'], 'fake-repo-tmpl', mocker.ANY,
     )
 
 
 def test_replay_load_template_name(
-        monkeypatch, mocker, user_config_data, user_config_file):
-    """Check that replay_load is called with a valid template_name that is
-    not a relative path.
+    monkeypatch, mocker, user_config_data, user_config_file
+):
+    """Check that replay_load is called correctly.
+
+    Calls require valid template_name that is not a relative path.
 
     Change the current working directory temporarily to 'tests/fake-repo-tmpl'
     for this test and call cookiecutter with '.' for the target template.
@@ -47,12 +49,9 @@ def test_replay_load_template_name(
     mocker.patch('cookiecutter.main.generate_files')
 
     cookiecutter(
-        '.',
-        replay=True,
-        config_file=user_config_file,
+        '.', replay=True, config_file=user_config_file,
     )
 
     mock_replay_load.assert_called_once_with(
-        user_config_data['replay_dir'],
-        'fake-repo-tmpl',
+        user_config_data['replay_dir'], 'fake-repo-tmpl',
     )
