@@ -1,8 +1,15 @@
 # -*- coding: utf-8 -*-
+
+"""Tests around handling repositories which require authentication."""
+
 from cookiecutter.prompt import read_repo_password
 
 
 def test_click_invocation(mocker):
+    """Test click function called correctly by cookiecutter.
+
+    Test for password (hidden input) type invocation.
+    """
     prompt = mocker.patch('click.prompt')
     prompt.return_value = 'sekrit'
 
