@@ -1,9 +1,6 @@
 # -*- coding: utf-8 -*-
 
-"""
-test_read_user_dict
--------------------
-"""
+"""Test `process_json`, `read_user_dict` functions in `cookiecutter.prompt`."""
 
 from __future__ import unicode_literals
 
@@ -17,6 +14,7 @@ from cookiecutter.prompt import (
 
 
 def test_process_json_invalid_json():
+    """Test `process_json` for correct error on malformed input."""
     with pytest.raises(click.UsageError) as exc_info:
         process_json('nope]')
 
@@ -24,6 +22,7 @@ def test_process_json_invalid_json():
 
 
 def test_process_json_non_dict():
+    """Test `process_json` for correct error on non-JSON input."""
     with pytest.raises(click.UsageError) as exc_info:
         process_json('[1, 2]')
 
@@ -31,6 +30,10 @@ def test_process_json_non_dict():
 
 
 def test_process_json_valid_json():
+    """Test `process_json` for correct output on JSON input.
+
+    Test for simple dict with list.
+    """
     user_value = '{"name": "foobar", "bla": ["a", 1, "b", false]}'
 
     assert process_json(user_value) == {
@@ -40,6 +43,10 @@ def test_process_json_valid_json():
 
 
 def test_process_json_deep_dict():
+    """Test `process_json` for correct output on JSON input.
+
+    Test for dict in dict case.
+    """
     user_value = '''{
         "key": "value",
         "integer_key": 37,
@@ -65,22 +72,15 @@ def test_process_json_deep_dict():
         "dict_key": {
             "deep_key": "deep_value",
             "deep_integer": 42,
-            "deep_list": [
-                "deep value 1",
-                "deep value 2",
-                "deep value 3",
-            ]
+            "deep_list": ["deep value 1", "deep value 2", "deep value 3"],
         },
-        "list_key": [
-            "value 1",
-            "value 2",
-            "value 3",
-        ]
+        "list_key": ["value 1", "value 2", "value 3"],
     }
 
 
 def test_should_raise_type_error(mocker):
-    prompt = mocker.patch('click.prompt')
+    """Test `default_value` arg verification in `read_user_dict` function."""
+    prompt = mocker.patch('cookiecutter.prompt.click.prompt')
 
     with pytest.raises(TypeError):
         read_user_dict('name', 'russell')
@@ -89,41 +89,32 @@ def test_should_raise_type_error(mocker):
 
 
 def test_should_call_prompt_with_process_json(mocker):
-    """Test to make sure that process_jon is actually being used
-    to generate a processor for the user input."""
+    """Test to make sure that `process_json` is actually being used.
 
-    mock_prompt = mocker.patch(
-        'cookiecutter.prompt.click.prompt',
-        autospec=True,
-    )
+    Verifies generation of a processor for the user input.
+    """
+    mock_prompt = mocker.patch('cookiecutter.prompt.click.prompt', autospec=True)
 
     read_user_dict('name', {'project_slug': 'pytest-plugin'})
 
     assert mock_prompt.call_args == mocker.call(
-        'name',
-        type=click.STRING,
-        default='default',
-        value_proc=process_json,
+        'name', type=click.STRING, default='default', value_proc=process_json,
     )
 
 
 def test_read_user_dict_default_value(mocker):
-    """Test to make sure that read_user_dict returns the default value for a
-    dict variable rather than the display value.
+    """Make sure that `read_user_dict` returns the default value.
+
+    Verify return of a dict variable rather than the display value.
     """
     mock_prompt = mocker.patch(
-        'cookiecutter.prompt.click.prompt',
-        autospec=True,
-        return_value='default',
+        'cookiecutter.prompt.click.prompt', autospec=True, return_value='default',
     )
 
     val = read_user_dict('name', {'project_slug': 'pytest-plugin'})
 
     assert mock_prompt.call_args == mocker.call(
-        'name',
-        type=click.STRING,
-        default='default',
-        value_proc=process_json,
+        'name', type=click.STRING, default='default', value_proc=process_json,
     )
 
     assert val == {'project_slug': 'pytest-plugin'}
