@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 
+"""Tests for cookiecutter's output directory customization feature."""
+
 import pytest
 
 from cookiecutter import main
@@ -20,11 +22,13 @@ def context():
 
 @pytest.fixture
 def output_dir(tmpdir):
+    """Fixture to prepare test output directory."""
     return str(tmpdir.mkdir('output'))
 
 
 @pytest.fixture
 def template(tmpdir):
+    """Fixture to prepare test template directory."""
     template_dir = tmpdir.mkdir('template')
     template_dir.join('cookiecutter.json').ensure(file=True)
     return str(template_dir)
@@ -32,20 +36,24 @@ def template(tmpdir):
 
 @pytest.fixture(autouse=True)
 def mock_gen_context(mocker, context):
+    """Fixture. Automatically mock cookiecutter's function with expected output."""
     mocker.patch('cookiecutter.main.generate_context', return_value=context)
 
 
 @pytest.fixture(autouse=True)
 def mock_prompt(mocker):
+    """Fixture. Automatically mock cookiecutter's function with expected output."""
     mocker.patch('cookiecutter.main.prompt_for_config')
 
 
 @pytest.fixture(autouse=True)
 def mock_replay(mocker):
+    """Fixture. Automatically mock cookiecutter's function with expected output."""
     mocker.patch('cookiecutter.main.dump')
 
 
 def test_api_invocation(mocker, template, output_dir, context):
+    """Verify output dir location is correctly passed."""
     mock_gen_files = mocker.patch('cookiecutter.main.generate_files')
 
     main.cookiecutter(template, output_dir=output_dir)
@@ -54,11 +62,13 @@ def test_api_invocation(mocker, template, output_dir, context):
         repo_dir=template,
         context=context,
         overwrite_if_exists=False,
-        output_dir=output_dir
+        skip_if_file_exists=False,
+        output_dir=output_dir,
     )
 
 
 def test_default_output_dir(mocker, template, context):
+    """Verify default output dir is current working folder."""
     mock_gen_files = mocker.patch('cookiecutter.main.generate_files')
 
     main.cookiecutter(template)
@@ -67,5 +77,6 @@ def test_default_output_dir(mocker, template, context):
         repo_dir=template,
         context=context,
         overwrite_if_exists=False,
-        output_dir='.'
+        skip_if_file_exists=False,
+        output_dir='.',
     )
