@@ -1,29 +1,24 @@
 # -*- coding: utf-8 -*-
 
-"""
-test_utils
-------------
-
-Tests for `cookiecutter.utils` module.
-"""
+"""Tests for `cookiecutter.utils` module."""
 
 import os
-import pytest
 import stat
 import sys
 
+import pytest
+
 from cookiecutter import utils
 
 
 def make_readonly(path):
-    """Helper function that is called in the tests to change the access
-    permissions of the given file.
-    """
+    """Change the access permissions to readonly for a given file."""
     mode = os.stat(path).st_mode
     os.chmod(path, mode & ~stat.S_IWRITE)
 
 
 def test_rmtree():
+    """Verify `utils.rmtree` remove files marked as read-only."""
     os.mkdir('foo')
     with open('foo/bar', "w") as f:
         f.write("Test data")
@@ -33,6 +28,11 @@ def test_rmtree():
 
 
 def test_make_sure_path_exists():
+    """Verify correct True/False response from `utils.make_sure_path_exists`.
+
+    Should return True if directory exist or created.
+    Should return False if impossible to create directory (for example protected)
+    """
     if sys.platform.startswith('win'):
         existing_directory = os.path.abspath(os.curdir)
         uncreatable_directory = 'a*b'
@@ -49,6 +49,7 @@ def test_make_sure_path_exists():
 
 
 def test_workin():
+    """Verify returning to original folder after `utils.work_in` use."""
     cwd = os.getcwd()
     ch_to = 'tests/files'
 
@@ -70,13 +71,10 @@ def test_workin():
 
 
 def test_prompt_should_ask_and_rm_repo_dir(mocker, tmpdir):
-    """In `prompt_and_delete()`, if the user agrees to delete/reclone the
-    repo, the repo should be deleted.
-    """
+    """In `prompt_and_delete()`, if the user agrees to delete/reclone the \
+    repo, the repo should be deleted."""
     mock_read_user = mocker.patch(
-        'cookiecutter.utils.read_user_yes_no',
-        return_value=True,
-        autospec=True
+        'cookiecutter.utils.read_user_yes_no', return_value=True, autospec=True
     )
     repo_dir = tmpdir.mkdir('repo')
 
@@ -87,14 +85,28 @@ def test_prompt_should_ask_and_rm_repo_dir(mocker, tmpdir):
     assert deleted
 
 
-def test_prompt_should_ask_and_rm_repo_file(mocker, tmpdir):
-    """In `prompt_and_delete()`, if the user agrees to delete/reclone a
-    repo file, the repo should be deleted.
-    """
+def test_prompt_should_ask_and_exit_on_user_no_answer(mocker, tmpdir):
+    """In `prompt_and_delete()`, if the user decline to delete/reclone the \
+    repo, cookiecutter should exit."""
     mock_read_user = mocker.patch(
-        'cookiecutter.utils.read_user_yes_no',
-        return_value=True,
-        autospec=True
+        'cookiecutter.utils.read_user_yes_no', return_value=False,
+    )
+    mock_sys_exit = mocker.patch('sys.exit', return_value=True)
+    repo_dir = tmpdir.mkdir('repo')
+
+    deleted = utils.prompt_and_delete(str(repo_dir))
+
+    assert mock_read_user.called
+    assert repo_dir.exists()
+    assert not deleted
+    assert mock_sys_exit.called
+
+
+def test_prompt_should_ask_and_rm_repo_file(mocker, tmpdir):
+    """In `prompt_and_delete()`, if the user agrees to delete/reclone a \
+    repo file, the repo should be deleted."""
+    mock_read_user = mocker.patch(
+        'cookiecutter.utils.read_user_yes_no', return_value=True, autospec=True
     )
 
     repo_file = tmpdir.join('repo.zip')
@@ -108,13 +120,10 @@ def test_prompt_should_ask_and_rm_repo_file(mocker, tmpdir):
 
 
 def test_prompt_should_ask_and_keep_repo_on_no_reuse(mocker, tmpdir):
-    """In `prompt_and_delete()`, if the user wants to keep their old
-    cloned template repo, it should not be deleted.
-    """
+    """In `prompt_and_delete()`, if the user wants to keep their old \
+    cloned template repo, it should not be deleted."""
     mock_read_user = mocker.patch(
-        'cookiecutter.utils.read_user_yes_no',
-        return_value=False,
-        autospec=True
+        'cookiecutter.utils.read_user_yes_no', return_value=False, autospec=True
     )
     repo_dir = tmpdir.mkdir('repo')
 
@@ -126,9 +135,9 @@ def test_prompt_should_ask_and_keep_repo_on_no_reuse(mocker, tmpdir):
 
 
 def test_prompt_should_ask_and_keep_repo_on_reuse(mocker, tmpdir):
-    """In `prompt_and_delete()`, if the user wants to keep their old
-    cloned template repo, it should not be deleted.
-    """
+    """In `prompt_and_delete()`, if the user wants to keep their old \
+    cloned template repo, it should not be deleted."""
+
     def answer(question, default):
         if 'okay to delete' in question:
             return False
@@ -136,9 +145,7 @@ def test_prompt_should_ask_and_keep_repo_on_reuse(mocker, tmpdir):
             return True
 
     mock_read_user = mocker.patch(
-        'cookiecutter.utils.read_user_yes_no',
-        side_effect=answer,
-        autospec=True
+        'cookiecutter.utils.read_user_yes_no', side_effect=answer, autospec=True
     )
     repo_dir = tmpdir.mkdir('repo')
 
@@ -150,13 +157,13 @@ def test_prompt_should_ask_and_keep_repo_on_reuse(mocker, tmpdir):
 
 
 def test_prompt_should_not_ask_if_no_input_and_rm_repo_dir(mocker, tmpdir):
-    """In `prompt_and_delete()`, if `no_input` is True, the call to
+    """Prompt should not ask if no input and rm dir.
+
+    In `prompt_and_delete()`, if `no_input` is True, the call to
     `prompt.read_user_yes_no()` should be suppressed.
     """
     mock_read_user = mocker.patch(
-        'cookiecutter.prompt.read_user_yes_no',
-        return_value=True,
-        autospec=True
+        'cookiecutter.prompt.read_user_yes_no', return_value=True, autospec=True
     )
     repo_dir = tmpdir.mkdir('repo')
 
@@ -168,13 +175,13 @@ def test_prompt_should_not_ask_if_no_input_and_rm_repo_dir(mocker, tmpdir):
 
 
 def test_prompt_should_not_ask_if_no_input_and_rm_repo_file(mocker, tmpdir):
-    """In `prompt_and_delete()`, if `no_input` is True, the call to
+    """Prompt should not ask if no input and rm file.
+
+    In `prompt_and_delete()`, if `no_input` is True, the call to
     `prompt.read_user_yes_no()` should be suppressed.
     """
     mock_read_user = mocker.patch(
-        'cookiecutter.prompt.read_user_yes_no',
-        return_value=True,
-        autospec=True
+        'cookiecutter.prompt.read_user_yes_no', return_value=True, autospec=True
     )
 
     repo_file = tmpdir.join('repo.zip')
